(function ($) {
	'use strict';

	jQuery(document).ready(function () {

		var list = {
			// Indicates that clicks should be ignored during an operation
			no_click_allowed: false,

			// added method display for getting first sets of data
			display: function() {
				var type = $("#mr-list-table").data('type');
				var action;
				if (type == 'mass') {
					action = 'mrwp_display_mass';
				} else {
					action = 'mrwp_display_history';
				}
				$.ajax( {
					url: ajaxurl,
					dataType: 'html',
					data: {
						mrwp_list_nonce: $("#mrwp_list_nonce").val(),
						action: action
					},
					success: function (response) {
						$("#mr-list-table").html(response);
						list.init();
					}
				} );
			},

			// events
			init: function () {
				var timer;
				var delay = 500;

				// Table changes
				$('.tablenav-pages a, .manage-column.sortable a, .manage-column.sorted a').on('click', function ( e ) {
					e.preventDefault();
					if (list.no_click_allowed) {
						return;
					}

					var query = this.search.substring( 1 );
					var data = {
						paged:         list.__query( query, 'paged' ) || '1',
						order:         list.__query( query, 'order' ),
						orderby:       list.__query( query, 'orderby' ),
						filter_etat:   $('#filter-by-status').val(),
						filter_mode:   $('#filter-by-mode').val(),
						date_from_iso: $('input[name=date-from-iso]').val(),
						date_to_iso:   $('input[name=date-to-iso]').val()
					};
					list.update( data );
				});

				// Filter
				$('#filter-submit').on('click', function ( e ) {
					e.preventDefault();
					if (list.no_click_allowed) {
						return;
					}

					// @todo Arriver à combiner l’ordre de tri et le filtrage
					// var query = this.search.substring( 1 );
					var data = {
						paged:         '1',
						// order:         list.__query( query, 'order' ),
						// orderby:       list.__query( query, 'orderby' ),
						filter_etat:   $('#filter-by-status').val(),
						filter_mode:   $('#filter-by-mode').val(),
						date_from_iso: $('input[name=date-from-iso]').val(),
						date_to_iso:   $('input[name=date-to-iso]').val()
					};
					list.update( data );
				});

				// Export CSV
				$('#export-submit').on('click', function ( e ) {
					e.preventDefault();
					if (list.no_click_allowed) {
						return;
					}

					// Preserving the sort order is not essential as it can easily be done in Excel (for example)
					var data = {
						filter_etat:   $('#filter-by-status').val(),
						filter_mode:   $('#filter-by-mode').val(),
						date_from:     $('input[name=date-from]').val(),
						date_to:       $('input[name=date-to]').val(),
						date_from_iso: $('input[name=date-from-iso]').val(),
						date_to_iso:   $('input[name=date-to-iso]').val()
					};
					list.export( data );
				});

				// Weight change – input
				$('a.update-weight').on('click', function (e) {
					e.preventDefault();
					if (list.no_click_allowed) {
						return;
					}

					var container = $(this).parent().find('span.weight');
					var weight    = container.html();

					// Hide edit icon
					$(this).hide();

					// Replace value with an <input>
					var html_input = '<input class="weight" data-id="' + container.data('id') + '" style="width: 60px" value="' + weight + '" /> ';
					var html_icons = ' <a class="dashicons dashicons-saved save-weight" data-id="' + container.data('id') + '"></a>';
					html_icons = html_icons  + ' <i class="dashicons dashicons-update spinner-weight" data-id="' + container.data('id') + '" style="display: none"></i>';
					container.html(html_input + html_icons);
				});

				// Weight change – save new value with Enter key
				$('table.table-view-list.expeditions').on('keypress', 'input.weight', function (e) {
					if (e.which == 13) {
						list.update_weight($(this));
					}
				});

				// Weight change – save new value with click on icon
				$('table.table-view-list.expeditions').on('click', 'a.save-weight', function (e) {
					var order_id = $(this).data('id');
					list.update_weight($('input.weight[data-id=' + order_id + ']'));
				});

				// Annuler une expédition
				$('a.cancel-expedition').on('click', function (e) {
					e.preventDefault();

					if (confirm('Voulez-vous vraiment annuler cette expédition ?')) {
						var container = $(this).parent().find('span.mode-liv');
						var order_id = $(this).data('id');

						// Manifest cancelation
						container.html('Ne pas expédier');

						// Disable checkbox
						var order_checkbox = $('#cb-select-' + order_id);
						order_checkbox.prop('disabled', true);

						// Mark row as ignored
						var order_row = order_checkbox.closest('tr');
						order_row.attr('data-status', 'ignore');

						// Hide icon
						$(this).hide();

						// Update order
						list.cancel_expedition(order_id);
					}
				});

				// Expeditions creation
				$('#create-expeditions').on('click', function (e) {
					e.preventDefault();
					if (list.no_click_allowed) {
						return;
					}

					$(this).hide();
					$('label#labels').html('Création des expéditions en cours').show();
					list.create_expedition();
				});

				// Retrieve shipping labels
				$('#retrieve-labels').on('click', function (e) {
					e.preventDefault();
					if (list.no_click_allowed) {
						return;
					}

					$(this).hide();
					$('#update-status').hide();
					$('label#labels').html('Récupération des étiquettes en cours').show();

					// Do we have checked orders?
					var orders_checked = $('input[name=orders]:checked');

					// Find all applicable orders
					if (orders_checked.length > 0) {
						var orders = $('tr input[name=orders]:checked');
					} else {
						var orders = $('tr input[name=orders]');
					}

					if (orders.length > 0) {
						list.get_labels(orders);
					}
				});

				// Update shipping status with click on icon
				$( '#history-buttons' ).on( 'click', 'a#update-status', function ( e ) {
					e.preventDefault();
					list.update_status();
				});

				$('#form-mass-expedition').on('submit', function(e) {
					e.preventDefault();
				});

				// Datepickers settings
				$('.datepicker[name=date-from]').datepicker({
					altField:  '#date-from-iso',
					altFormat: 'yy-mm-dd',
					autoSize:  true,
					defaultDate: 0
				});
				$('.datepicker[name=date-to]').datepicker({
					altField:  '#date-to-iso',
					altFormat: 'yy-mm-dd',
					autoSize:  true,
					defaultDate: 0
				});
			},

			// AJAX call Send the call and replace table parts with updated version!
			update: function(data) {
				var type = $("#mr-list-table").data('type');
				var action;
				if (type == 'mass') {
					action = 'mrwp_refresh_mass';
				} else {
					action = 'mrwp_refresh_history';
				}
				$.ajax({
					url: ajaxurl,
					dataType: 'json',
					data: $.extend(
						{
							mrwp_list_nonce: $("#mrwp_list_nonce").val(),
							action: action
						},
						data
					),
					success: function( response ) {
						if (response.rows.length)
							$('#the-list').html(response.rows);
						if (response.column_headers.length)
							$('table.expeditions thead tr, table.expeditions tfoot tr').html(response.column_headers);
						if (response.pagination.bottom.length)
							$('.tablenav.top .tablenav-pages').html($(response.pagination.top).html());
						if (response.pagination.top.length)
							$('.tablenav.bottom .tablenav-pages').html($(response.pagination.bottom).html());
						if (response.buttons.length)
							$('#history-buttons').html($(response.buttons).html());
						list.init();
					}
				});
			},

			// AJAX Export filtered data to CSV
			export: function( data ) {
				$.ajax({
					url: ajaxurl,
					data: $.extend(
						{
							mrwp_list_nonce: $("#mrwp_list_nonce").val(),
							action: 'mrwp_export_history'
						},
						data
					),
					xhrFields: {
						responseType: 'blob'
					},
					success: function( blob, status, xhr ) {
						var URL = window.URL || window.webkitURL;
						var downloadUrl = URL.createObjectURL( blob );

						// use HTML5 a[download] attribute to specify filename
						var a = document.createElement( 'a' );
						// safari doesn't support this yet
						if ( typeof a.download === 'undefined' ) {
							window.location.href = downloadUrl;
						} else {
							a.href = downloadUrl;
							a.download = 'mondial-relay-export.csv';
							document.body.appendChild( a );
							a.click();
						}

						// Cleanup
						// For Firefox it is necessary to delay revoking the ObjectURL
						setTimeout( function () {
							URL.revokeObjectURL( downloadUrl );
							document.body.removeChild( a );
						}, 100 );
					}
				});
			},

			// AJAX save updated weight
			update_weight: function(element) {

				// No other operation allowed during updates
				list.no_click_allowed = true;

				// Hide button to prevent multiple clicks
				$('.save-weight').hide();
				$('.spinner-weight[data-id=' + order_id + ']').show();

				// Send value
				var order_id   = element.data('id');
				var new_weight = element.val();

				// Display spinner
				$('.spinner-weight[data-id=' + order_id + ']').show();

				$.ajax({
					url: ajaxurl,
					type: 'POST',
					dataType: 'json',
					data: {
						mrwp_list_nonce: $("#mrwp_list_nonce").val(),
						action:  'mrwp_update_weight',
						order_id: order_id,
						weight:   new_weight
					},
					success: function(response) {
						console.log(response);

						// 1. Remove <input> and icons, and display new value
						var container = $('span.weight[data-id=' + response.order_id + ']');
						container.html(response.weight);

						// 2. Show edit icon again
						var icon = container.closest('td').find('a.update-weight');
						icon.show();

						// 3. Allow other operations
						list.no_click_allowed = false;
					}
				});
			},

			// AJAX Permanently cancel expedition
			cancel_expedition: function(order_id) {
				$.ajax({
					url: ajaxurl,
					type: 'POST',
					dataType: 'json',
					data: {
						mrwp_list_nonce: $("#mrwp_list_nonce").val(),
						action:  'mrwp_cancel_expedition',
						order_id: order_id
					},
					success: function(response) {
						console.log(response);
					}
				});
			},

			/*
			* Process one expedition then call itself recursively
			*
			* If we have selected orders
			* - process the first selected order
			* If no order is selected
			* - process the first order
			* Redo until there are no more unprocessed orders
			*/
			create_expedition: function() {

				// No other operation allowed during updates
				list.no_click_allowed = true;

				// Do we have checked orders?
				var orders_checked = $('input[name=orders]:checked');

				// Find all applicable orders without a data-status yet
				if (orders_checked.length > 0) {
					var remaining_orders = $('tr:not([data-status]) input[name=orders]:checked');
				} else {
					var remaining_orders = $('tr:not([data-status]) input[name=orders]');
				}

				// If there are unprocessed orders, process the first one
				if (remaining_orders.length > 0) {
					var order_id = remaining_orders.val();

					$.ajax({
						url: ajaxurl,
						method: "POST",
						data: {
							mrwp_list_nonce: $("#mrwp_list_nonce").val(),
							action: 'mrwp_create_expedition',
							numcom: order_id
						},
						dataType: "json",
						success: function (response) {

							// Find the <input>
							var order_checkbox = $('input#cb-select-' + response.numcom);

							// Find the row <tr>
							var order_row = order_checkbox.closest('tr');

							// Test if (response.success), set <tr data-status=""> accordingly
							if (response.success) {
								order_row.attr('data-status', 'success');
								order_row.attr('data-numexp', response.numexp); // Expedition number
								// @todo Ajouter une icône Succès
								// @todo Flash vert sur la ligne ?
								order_row.find('td.column-Expedition').html('n°' + response.numexp);
							} else {
								order_row.attr('data-status', 'failure');
								order_row.attr('data-numexp', response.numexp); // should be 0
								// @todo Ajouter une icône Échec
								order_row.find('td.column-Expedition').html(response.message);
							}

							// Call function again until orders_all.length == 0
							list.create_expedition();
						}
					});
				} else {
					/*
					* No more orders to send.
					* If we have at least 1 successful expedition, get labels
					*/
					var numexps = $('tr[data-status=success][data-numexp]');
					if (numexps.length > 0) {
						list.get_labels(numexps);
					}

					// Show button again and allow other operations
					//$('#create-expeditions').show();
					list.no_click_allowed = false;
				}
			},

			// AJAX call etiquettes
			get_labels: function(elements) {
				var numexp_list = '';

				elements.each(function() {
					if ($(this).data('numexp') != 0) {
						numexp_list = numexp_list + $(this).data('numexp') + ';';
					}
				});
				numexp_list = numexp_list.slice(0, -1);
				$.ajax({
					url: ajaxurl,
					type: "POST",
					dataType: "json",
					data: {
						mrwp_list_nonce: $("#mrwp_list_nonce").val(),
						action: 'mrwp_impression',
						numcom: numexp_list
					},
					success: function(response) {
						console.log(response);
						if ( response.STAT != '0' ) {
							$('label#labels').html('Étiquettes indisponibles, erreur n°' + response.STAT).show();
						} else {
							$('label#labels').html('Étiquettes disponibles').show();

							// On met à jour les URL des liens et on les affiche
							$('#ea4').attr('href', 'https://www.mondialrelay.fr/' + response.URL_PDF_A4).show();
							$('#ea5').attr('href', 'https://www.mondialrelay.fr/' + response.URL_PDF_A5).show();
							$('#ea10').attr('href', 'https://www.mondialrelay.fr/' + response.URL_PDF_10x15).show();
						}
					}
				});
			},

			update_status: function( button ) {

				/*
				 * Is there a shipment to be updated?
				 *
				 * Shipment numbers have a data-expedition_num attribute that
				 * is removed upon update
				 */
				var shipment = $('[data-expedition_num]').first();

				if ( shipment.length != 0 ) {

					// No other operation allowed during update
					list.no_click_allowed = true;

					// Get shipment number
					var shipment_number = shipment.data( 'expedition_num' );

					// Remove attribute from element so it isn’t processed a second time
					shipment.removeAttr( 'data-expedition_num' );

					if ( shipment_number != 0 ) {

						// Add spinner after shipment number
						shipment.append( ' <i class="dashicons dashicons-update spinner-status spin"></i>' );

						$.ajax( {
							url: ajaxurl,
							type: 'POST',
							dataType: 'json',
							data: {
								mrwp_list_nonce: $( '#mrwp_list_nonce' ).val(),
								shipment_number: shipment_number,
								action:          'mrwp_update_status'
							},
							success: function( response ) {
								if ( response.code ) {
									shipment.html( response.text );
									if ( 'updated' == response.status ) {
										shipment.addClass( 'updated' );
									} else if ( 'unchanged' == response.status || 'too-fast' == response.status ) {
										shipment.addClass( 'unchanged' );
									} else if ( 'error' == response.status ) {
										shipment.addClass( 'error' );
									}
								}

								// Call again for next order
								list.update_status();
							},
							complete: function() {
								list.no_click_allowed = false;

								// Remove spinner
								$( '.spinner-status' ).remove();
							}
						});

					} else {

						// Shipment number is 0, immediately call function again for next order
						list.update_status();
						list.no_click_allowed = false;
					}
				}
			},

			/**
			 * Filter the URL Query to extract variables
			 *
			 * @see http://css-tricks.com/snippets/javascript/get-url-variables/
			 *
			 * @param    string    query The URL query part containing the variables
			 * @param    string    variable Name of the variable we want to get
			 *
			 * @return   string|boolean The variable value if available, false else.
			 */
			__query: function (query, variable) {
				var vars = query.split("&");
				for (var i = 0; i < vars.length; i++) {
					var pair = vars[i].split("=");
					if (pair[0] == variable)
						return pair[1];
				}
				return false;
			},
		}

		list.display();
	});
})(jQuery);
