<?php
/*
Plugin Name:  Mondial Relay - WordPress
Plugin URI:   https://mondialrelay-wp.com
Description:  Official Plugin for Mondial Relay on WordPress and WooCommerce
Version:      3.4
Author:       Rodolphe Cazemajou-Tournié
Author URI:   https://kasutan.pro/
License:      GPL3
License URI:  https://www.gnu.org/licenses/gpl-3.0.html
Text Domain:  mondialrelay-wordpress
Domain Path:  /languages
WC requires at least: 3.1
WC tested up to: 6.9
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Check if WooCommerce is active
if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
    require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
}

if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    if ( ! is_plugin_active_for_network( 'woocommerce/woocommerce.php' ) ) {
        return;
    }
}

// EDD Automatic Updates
// this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
define( 'MRWP_STORE_URL', 'https://mondialrelay-wp.com' );

// the download ID for the product in Easy Digital Downloads
// @todo Refactoring utiliser la constante MRWP_ITEM_ID plutôt que la valeur 31
define( 'MRWP_ITEM_ID', 31 );

// @todo Refactoring Homogénéiser la gestion de version du plugin

if ( !class_exists( 'EDD_SL_Plugin_Updater' ) )
{
	// load our custom updater
	include( dirname( __FILE__ ) . '/admin/EDD/EDD_SL_Plugin_Updater.php' );
}

function MRWP_plugin_updater()
{
	// retrieve our license key from the DB
	$license_key = trim( get_option( 'mondialrelay_license_key' ) );

	// setup the updater
	$edd_updater = new EDD_SL_Plugin_Updater( 'https://mondialrelay-wp.com', __FILE__,
		array(
			'version' => '3.4',                    // current version number
			'license' => $license_key,             // license key (used get_option above to retrieve from DB)
			'item_id' => 31,       // ID of the product
            'author'  => 'Mondial Relay - WordPress', // author of this plugin
            'url'     => home_url(),
			'beta'    => false,
		)
	);

}
add_action( 'admin_init', 'MRWP_plugin_updater', 0 );

// Plugin installation
function MRWP_install()
{
    require_once plugin_dir_path(__FILE__) . 'inc/class-MRWP-install.php';
    class_MRWP_install::install();
}
register_activation_hook(__FILE__, 'MRWP_install');

// Execution of the plugin
require plugin_dir_path(__FILE__) . 'inc/class-MRWP-main.php';

function run_MRWP()
{
    $plugin = new class_MRWP_main();
    $plugin->run();
}

// Check PHP version of the server
require_once plugin_dir_path(__FILE__) . 'inc/class-MRWP-php.php';
$updatePhp = new class_MRWP_php('5.6.0');
if ($updatePhp->php_version_check(PHP_VERSION)) {
    run_MRWP();
}
