<?php

  // Public part of the plugin

class class_MRWP_public {

// Privaye var
	private $plugin_name; // ID of this plugin
	private $version; // Current version of the plugin
    private $dev; // Development mode
    private $debug; // Debug mode

// Initialize the class and set its properties
	public function __construct( $plugin_name, $version, $dev, $debug ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
        $this->dev = $dev;
        $this->debug = $debug;
	}

// Register the stylesheets for the public-facing side of the site
	public function enqueue_styles() {
		// Load only on checkout page
		if (!is_checkout()) return false;
		// Load generals scripts/styles
		wp_enqueue_style('mondial-relay-plugin-css', plugin_dir_url(dirname(__FILE__)).'public/css/mrwp.css');
        // Load Modaal styles
        wp_enqueue_style('mondial-relay-modaal-css', plugin_dir_url(dirname(__FILE__)).'public/modaal/modaal.min.css');
        // Load leaflet styles
		wp_enqueue_style('mondialrelay-leaflet-css', '//unpkg.com/leaflet/dist/leaflet.css');
	}

// Register the scripts for the public-facing side of the site
	public function enqueue_scripts() {

		// Load only on checkout page
		if (is_checkout()){

            // Header or Footer
            $mondialrelay_jquery = get_option('mondialrelay_jquery', class_MRWP_main::MRJAVA);

            // Dependencies
            $dependencies = array('jquery', 'woocommerce');

            // Modaal
            if ($mondialrelay_jquery) {
                wp_register_script('mondialrelay-modaal', plugin_dir_url(dirname(__FILE__)) . 'public/modaal/modaal.min.js', $dependencies, '2.1', false);
            } else {
                wp_register_script('mondialrelay-modaal', plugin_dir_url(dirname(__FILE__)) . 'public/modaal/modaal.min.js', $dependencies, '2.1', true);
            }
            wp_enqueue_script('mondialrelay-modaal');
            array_push($dependencies, 'mondialrelay-modaal');

            // Leaflet For Map
            if ($mondialrelay_jquery) {
                wp_register_script('mondialrelay-leaflet-maps', '//unpkg.com/leaflet/dist/leaflet.js', [], false, false);
            } else {
                wp_register_script('mondialrelay-leaflet-maps', '//unpkg.com/leaflet/dist/leaflet.js', [], false, true);
            }
            wp_enqueue_script('mondialrelay-leaflet-maps');
            array_push($dependencies, 'mondialrelay-leaflet-maps');

            // Mondial Relay Parcelshop Picker
            $parcelshop_picker = str_replace('.', '_', class_MRWP_main::PARCELSHOP_PICKER);

            if ($mondialrelay_jquery) {
                wp_register_script('mondialrelay-parcelshoppicker', 'https://widget.mondialrelay.com/parcelshop-picker/jquery.plugin.mondialrelay.parcelshoppicker.min.js', $dependencies, false, false);
            } else {
                wp_register_script('mondialrelay-parcelshoppicker', 'https://widget.mondialrelay.com/parcelshop-picker/jquery.plugin.mondialrelay.parcelshoppicker.min.js', $dependencies, false, true);
            }
            wp_enqueue_script('mondialrelay-parcelshoppicker' );
            array_push($dependencies, 'mondialrelay-parcelshoppicker');

            // Load Mondial Relay script file
            if ($mondialrelay_jquery) {
                //wp_register_script('mondialrelay-wp', plugin_dir_url(dirname(__FILE__)).'public/js/mondialrelay.js?v='. $this->version, $dependencies);
                wp_register_script('mondialrelay-wp', plugin_dir_url(dirname(__FILE__)).'public/js/mondialrelay.min.js', $dependencies, $this->version, false);
            } else {
                //wp_register_script('mondialrelay-wp', plugin_dir_url(dirname(__FILE__)).'public/js/mondialrelay.js?v='. $this->version, $dependencies);
                wp_register_script('mondialrelay-wp', plugin_dir_url(dirname(__FILE__)).'public/js/mondialrelay.min.js', $dependencies, $this->version, true);
            }
            // Localize the script with plugin settings
            $data_for_script = $this->data_for_script();
            wp_localize_script( 'mondialrelay-wp', 'mrwpPluginSettings', $data_for_script );
            wp_enqueue_script('mondialrelay-wp');
            array_push($dependencies, 'mondialrelay-wp');

        // Load only on cart page
        }  else if( is_cart() ) {

            // Dependencies
            $cart_dependencies = array('jquery', 'woocommerce');

             // Load Mondial Relay script file for cart page
             //wp_register_script('mondialrelay-wp-cart', plugin_dir_url(dirname(__FILE__)).'public/js/mondialrelay-cart.js?v='. $this->version, $cart_dependencies);
             wp_register_script('mondialrelay-wp-cart', plugin_dir_url(dirname(__FILE__)).'public/js/mondialrelay-cart.min.js', $cart_dependencies, $this->version, true);

             // Localize the script with plugin settings
             $data_for_cart_script = $this->data_for_cart_script();

             wp_localize_script( 'mondialrelay-wp-cart', 'mrwpPluginSettings', $data_for_cart_script );
             wp_enqueue_script('mondialrelay-wp-cart');
             array_push($cart_dependencies, 'mondialrelay-wp-cart');

        }

	}

// Get unavailable MR shipping options above 30kg
    public function not_above_30($mondialrelay_ids_livraison) {
        $mondialrelay_poids = get_option('mondialrelay_poids', 0);
        $unavailable_ids=array();
        if (is_array($mondialrelay_ids_livraison) && !$mondialrelay_poids) {
            foreach($mondialrelay_ids_livraison as $id_livraison) {
                if(strpos($id_livraison, '-') !== false){
                    $id_livraison=explode('-',$id_livraison);
                    $code=$id_livraison[1];
                    $flat_rate=$id_livraison[0];
                    if (in_array($code,array('24R','HOM','HOC','HOD'))) {
                        array_push($unavailable_ids,$flat_rate);
                    }
                }
            }
        }
        return $unavailable_ids;
    }

// Get unavailable MR shipping options above 70kg
public function not_above_70($mondialrelay_ids_livraison) {
    $mondialrelay_poids = get_option('mondialrelay_poids', 0);
    $unavailable_ids=array();
    if (is_array($mondialrelay_ids_livraison) && !$mondialrelay_poids) {
        foreach($mondialrelay_ids_livraison as $id_livraison) {
            if(strpos($id_livraison, '-') !== false){
                $id_livraison=explode('-',$id_livraison);
                $code=$id_livraison[1];
                $flat_rate=$id_livraison[0];
                if (in_array($code,array('LD1'))) {
                    array_push($unavailable_ids,$flat_rate);
                }
            }
        }
    }
    return $unavailable_ids;
}
// Get unavailable MR shipping options above 130kg
public function not_above_130($mondialrelay_ids_livraison) {
    $mondialrelay_poids = get_option('mondialrelay_poids', 0);
    $unavailable_ids=array();
    if (is_array($mondialrelay_ids_livraison) && !$mondialrelay_poids) {
        foreach($mondialrelay_ids_livraison as $id_livraison) {
            if(strpos($id_livraison, '-') !== false){
                $id_livraison=explode('-',$id_livraison);
                $code=$id_livraison[1];
                $flat_rate=$id_livraison[0];
                if (in_array($code,array('DRI','LDS'))) {
                    array_push($unavailable_ids,$flat_rate);
                }
            }
        }
    }
    return $unavailable_ids;
}
// Get Mondial Relay configuration parameters and prepare an array for localizing CART script
    public function data_for_cart_script() {
        $data=array();
        $mondialrelay_ids_livraison = get_option( 'mondialrelay_ids_livraison', 1 );
        $data['all_shipping_ids']= json_encode($mondialrelay_ids_livraison);
        $data['not_above_30']=json_encode($this->not_above_30($mondialrelay_ids_livraison));
        $data['not_above_70']=json_encode($this->not_above_70($mondialrelay_ids_livraison));
        $data['not_above_130']=json_encode($this->not_above_130($mondialrelay_ids_livraison));
        $data['error_no_shipping_method']=__('Aucune méthode de livraison disponible pour un panier de ce poids.','mondialrelay-wordpress');
        $data['error_block_checkout']=__('Veuillez ajuster le nombre d\'articles dans votre panier.','mondialrelay-wordpress');
        //TODO pass flat_rate info for each weight group
        return $data;
    }
// Get cart weight and convert to grams
    public function cart_weight_to_grams() {
        global $woocommerce;

        // Weight calculation
        $Weight = $woocommerce->cart->cart_contents_weight;
        $unit = get_option('woocommerce_weight_unit', 0);
        if ($unit == 'kg') {
            $Weight = $Weight * 1000;
        } elseif ($unit == 'lbs') {
            $Weight = $Weight * 453.59237;
        } elseif ($unit == 'oz') {
            $Weight = $Weight * 28.3495231;
        }

        // Round in an integer due to the Mondial Relay API
        $Weight = round($Weight, 0);
        return $Weight;
    }

    // Get Mondial Relay configuration parameters and prepare an array for localizing script
    public function data_for_script()
    {
        $params = class_MRWP_order::get_params_checkout();  // Refactoring: fold in
        $data_for_script = array();  // Refactoring: not a good name, this is not Basic
        foreach ($params as $param) {
            $champ = get_option( $param, 1 );
			if ($param == 'mondialrelay_ids_livraison') {
			    $champ = json_encode($champ);
            }
            $data_for_script[$param]=$champ;
        }

        $Weight = $this->cart_weight_to_grams(); // Refactoring: use WooCommerce conversion

        $data_for_script['mondialrelay_weight']=$Weight;

        //Add paramaters for screening shipping methods according to weight
        $data_for_script=array_merge($data_for_script,$this->data_for_cart_script());

        //Add new error messages
        $data_for_script['back_to_cart']='<a href="'.wc_get_cart_url().'">'.__("Revenir au panier","mondialrelay-wordpress").'</a>';

        return $data_for_script;
    }

// Add Cart weight as a HIDDEN row to to Cart and Checkout

    public function display_cart_weight() {
	?>
	    <tr style="display:none">
            <th><?php _e( 'Total Weight (g)', 'mondialrelay-wordpress' ); ?></th>
            <td id="mrwp_updated_weight"><?php echo $this->cart_weight_to_grams(); ?></td>
	    </tr>
        <?php
}
// Modaal link
    public function modaal_link() {
        if (!is_checkout()) return false;

        //https://github.com/woocommerce/woocommerce/issues/14792
        //Needs a table row or will be rewritten when Woo updates Ajax
        ob_start();
        ?>
        <tr class="mrwp" style="display:none">
            <th><?php echo __('Livraison Mondial Relay','mondialrelay-wordpress');?>
            <br>
            <em id="parcel_shop_info"><?php echo __("Vous n'avez pas encore choisi de Point Relais®",'mondialrelay-wordpress');?></em>
            </th>
            <td><a id="modaal_link" href="#modaal"><?php echo  __('Choisir un Point Relais®', 'mondialrelay-wordpress'); ?></a></td>
        </tr>

        <?php
        $htmloutput = ob_get_clean();
        
        // Filter to change appearance of the modaal link part
        echo apply_filters( 'mrwp_modaal_link', $htmloutput );
    }

//Modaal content
    public function modaal_content() {
        // Load only on checkout page
        if (!is_checkout()) return false;

        $http_accept_language = $_SERVER['HTTP_ACCEPT_LANGUAGE'];
        $supported_languages = array("fr","es","nl","en");
        $supported_languages = array_flip($supported_languages);

        preg_match_all('~([\w-]+)(?:[^,\d]+([\d.]+))?~', strtolower($http_accept_language), $matches, PREG_SET_ORDER);

        $available_languages = array();

        $compteur = 0;
        foreach ($matches as $match) {
            list($language_code,$language_region) = explode('-', $match[1]) + array('', '');
            if (isset($match[2])) {
                $priority = (float) $match[2];
            } elseif ($compteur == 0) {
                $priority = 0.1;
            } else {
                $priority = 1.0;
            }
            $available_languages[][$language_code] = $priority;
            $compteur = $compteur + 1;
        }

        $default_priority = (float) 0;
        $default_language_code = 'en';

        foreach ($available_languages as $key => $value) {
            $language_code = key($value);
            $priority = $value[$language_code];

            if ($priority > $default_priority && array_key_exists($language_code,$supported_languages)) {
                $default_priority = $priority;
                $default_language_code = $language_code;
            }
        }

        if( $default_language_code == 'fr' ) {
            $texte1 = 'Veuillez choisir un Point Relais®';
            $texte2 = 'Choisir ce Point Relais®';
        } elseif( $default_language_code == 'es' ) {
            $texte1 = 'Gracias por seleccionar un Punto Pack®';
            $texte2 = 'Elegir este Punto Pack®';
        } elseif( $default_language_code == 'nl' ) {
            $texte1 = 'Gelieve een Afhaalpunt® kiezen';
            $texte2 = 'Dit Afhaalpunt® kiezen';
        } else {
            $texte1 = 'Please choose a Point Relais®';
            $texte2 = 'Choose this Point Relais®';
        }

        ?>
        <div id="modaal" style="display:none">
            <div>
                <div id="parcel_picker"></div>
                <div id="mondial_relay_alert" class="alert" style="display:none">
                    <?php echo $texte1;?>
                </div>
                <button id="delivery_point_chosen">
                    <?php echo $texte2;?>
                </button>
            </div>
        </div>
        <?php
    }

// Create Mondial Relay Custom Fields on Checkout Page
    public function my_custom_checkout_field($checkout) {
        // Load only on checkout page
        if (!is_checkout()) return false;
        echo '<div style="display:none"><h2>';
        _e('Mondial Relay Delivery - Hidden in production', 'mondialrelay-wordpress');
        echo '</h2>';
        woocommerce_form_field( 'mrwp_parcel_shop_id', array(
            'type'          => 'text',
            'label'         => __('Mondial Relay Parcel Shop ID', 'mondialrelay-wordpress'),
            'placeholder'       => '',
        ), $checkout->get_value( 'mrwp_parcel_shop_id' ));
        woocommerce_form_field( 'mrwp_user_lang', array(
            'type'          => 'text',
            'label'         => __('Mondial Relay User Lang', 'mondialrelay-wordpress'),
            'placeholder'       => '',
        ), $checkout->get_value( 'mrwp_user_lang' ));
        woocommerce_form_field( 'mrwp_parcel_shop_address', array(
            'type'          => 'textarea',
            'label'         => __('Mondial Relay Parcel Shop Address', 'mondialrelay-wordpress'),
            'placeholder'       => '',
        ), $checkout->get_value( 'mrwp_parcel_shop_address' ));
        woocommerce_form_field( 'mrwp_shipping_code', array(
            'type'          => 'text',
            'label'         => __('Mondial Relay Shipping Code', 'mondialrelay-wordpress'),
            'placeholder'       => 'placeholder pour code expédition',
        ), $checkout->get_value( 'mrwp_shipping_code' ));
        woocommerce_form_field( 'mrwp_parcel_shop_mandatory', array(
            'type'          => 'text',
            'label'         => __('This shipping code requires a parcel shop ID', 'mondialrelay-wordpress'),
            'default'       => 'No',
        ), $checkout->get_value( 'mrwp_parcel_shop_mandatory' ));
        woocommerce_form_field( 'mrwp_weight', array(
            'type'          => 'text',
            'label'         => __('Parcel Weight', 'mondialrelay-wordpress'),
        ), $checkout->get_value( 'mrwp_weight' ));
        woocommerce_form_field( 'mrwp_too_heavy_block_checkout', array(
            'type'          => 'text',
            'label'         => __('Weight too heavy, block checkout', 'mondialrelay-wordpress'),
            'default'       => 'No'
        ), $checkout->get_value( 'mrwp_too_heavy_block_checkout' ));
        echo '</div>';
    }

}